@@ -22,6 +22,20 @@ Conversely, CDK will not fail on synth if warnings are detected. To enforce that
 ```shell
 cdk synth --strict
 ```
+
+### Instrumenting custom NagPacks
+
+By default, when creating a PDKNag application the [AwsSolutions](https://github.com/cdklabs/cdk-nag/blob/main/RULES.md) NagPack is instrumented. In order to specify custom NagPacks to instrument, you can configure the PDKApp as follows:
+
+```python
+import { PDKNag, AwsPrototypingChecks } from "@aws-prototyping-sdk/pdk-nag";
+
+const app = PDKNag.app({
+    nagPacks: [new AwsPrototypingChecks()]
+});
+```
+
+In this example, the [AwsPrototypingChecks](https://github.com/aws/aws-prototyping-sdk/blob/mainline/packages/pdk-nag/src/packs/README.md) NagPack has been configured to run instead of the default. Multiple NagPacks can also be instrumented by adding NagPack instances to the `nagPacks` array;
 '''
 import abc
 import builtins
@@ -245,6 +259,7 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="@aws-prototyping-sdk/pdk-nag.PD
         *,
         fail_on_error: typing.Optional[builtins.bool] = None,
         fail_on_warning: typing.Optional[builtins.bool] = None,
+        nag_packs: typing.Optional[typing.Sequence[cdk_nag.NagPack]] = None,
         analytics_reporting: typing.Optional[builtins.bool] = None,
         auto_synth: typing.Optional[builtins.bool] = None,
         context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
@@ -257,6 +272,7 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="@aws-prototyping-sdk/pdk-nag.PD
 
         :param fail_on_error: Determines whether any errors encountered should trigger a test failure. Default: false
         :param fail_on_warning: Determines whether any warnings encountered should trigger a test failure. Default: false
+        :param nag_packs: Custom nag packs to execute. Default: DEFAULT_NAG_PACKS
         :param analytics_reporting: Include runtime versioning information in the Stacks of this app. Default: Value of 'aws:cdk:version-reporting' context key
         :param auto_synth: Automatically call ``synth()`` before the program exits. If you set this, you don't have to call ``synth()`` explicitly. Note that this feature is only available for certain programming languages, and calling ``synth()`` is still recommended. Default: true if running via CDK CLI (``CDK_OUTDIR`` is set), ``false`` otherwise
         :param context: Additional context values for the application. Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
@@ -268,6 +284,7 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="@aws-prototyping-sdk/pdk-nag.PD
         props = PDKNagAppProps(
             fail_on_error=fail_on_error,
             fail_on_warning=fail_on_warning,
+            nag_packs=nag_packs,
             analytics_reporting=analytics_reporting,
             auto_synth=auto_synth,
             context=context,
@@ -352,6 +369,7 @@ class PDKNagApp(
         *,
         fail_on_error: typing.Optional[builtins.bool] = None,
         fail_on_warning: typing.Optional[builtins.bool] = None,
+        nag_packs: typing.Optional[typing.Sequence[cdk_nag.NagPack]] = None,
         analytics_reporting: typing.Optional[builtins.bool] = None,
         auto_synth: typing.Optional[builtins.bool] = None,
         context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
@@ -363,6 +381,7 @@ class PDKNagApp(
         '''
         :param fail_on_error: Determines whether any errors encountered should trigger a test failure. Default: false
         :param fail_on_warning: Determines whether any warnings encountered should trigger a test failure. Default: false
+        :param nag_packs: Custom nag packs to execute. Default: DEFAULT_NAG_PACKS
         :param analytics_reporting: Include runtime versioning information in the Stacks of this app. Default: Value of 'aws:cdk:version-reporting' context key
         :param auto_synth: Automatically call ``synth()`` before the program exits. If you set this, you don't have to call ``synth()`` explicitly. Note that this feature is only available for certain programming languages, and calling ``synth()`` is still recommended. Default: true if running via CDK CLI (``CDK_OUTDIR`` is set), ``false`` otherwise
         :param context: Additional context values for the application. Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
@@ -374,6 +393,7 @@ class PDKNagApp(
         props = PDKNagAppProps(
             fail_on_error=fail_on_error,
             fail_on_warning=fail_on_warning,
+            nag_packs=nag_packs,
             analytics_reporting=analytics_reporting,
             auto_synth=auto_synth,
             context=context,
@@ -433,6 +453,11 @@ class PDKNagApp(
 
         return typing.cast(aws_cdk.cx_api.CloudAssembly, jsii.invoke(self, "synth", [options]))
 
+    @builtins.property
+    @jsii.member(jsii_name="nagPacks")
+    def nag_packs(self) -> typing.List[cdk_nag.NagPack]:
+        return typing.cast(typing.List[cdk_nag.NagPack], jsii.get(self, "nagPacks"))
+
 
 @jsii.data_type(
     jsii_type="@aws-prototyping-sdk/pdk-nag.PDKNagAppProps",
@@ -447,6 +472,7 @@ class PDKNagApp(
         "tree_metadata": "treeMetadata",
         "fail_on_error": "failOnError",
         "fail_on_warning": "failOnWarning",
+        "nag_packs": "nagPacks",
     },
 )
 class PDKNagAppProps(aws_cdk.AppProps):
@@ -462,6 +488,7 @@ class PDKNagAppProps(aws_cdk.AppProps):
         tree_metadata: typing.Optional[builtins.bool] = None,
         fail_on_error: typing.Optional[builtins.bool] = None,
         fail_on_warning: typing.Optional[builtins.bool] = None,
+        nag_packs: typing.Optional[typing.Sequence[cdk_nag.NagPack]] = None,
     ) -> None:
         '''
         :param analytics_reporting: Include runtime versioning information in the Stacks of this app. Default: Value of 'aws:cdk:version-reporting' context key
@@ -473,6 +500,7 @@ class PDKNagAppProps(aws_cdk.AppProps):
         :param tree_metadata: Include construct tree metadata as part of the Cloud Assembly. Default: true
         :param fail_on_error: Determines whether any errors encountered should trigger a test failure. Default: false
         :param fail_on_warning: Determines whether any warnings encountered should trigger a test failure. Default: false
+        :param nag_packs: Custom nag packs to execute. Default: DEFAULT_NAG_PACKS
 
         :inheritDoc: true
         '''
@@ -488,6 +516,7 @@ class PDKNagAppProps(aws_cdk.AppProps):
                 tree_metadata: typing.Optional[builtins.bool] = None,
                 fail_on_error: typing.Optional[builtins.bool] = None,
                 fail_on_warning: typing.Optional[builtins.bool] = None,
+                nag_packs: typing.Optional[typing.Sequence[cdk_nag.NagPack]] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -500,6 +529,7 @@ class PDKNagAppProps(aws_cdk.AppProps):
             check_type(argname="argument tree_metadata", value=tree_metadata, expected_type=type_hints["tree_metadata"])
             check_type(argname="argument fail_on_error", value=fail_on_error, expected_type=type_hints["fail_on_error"])
             check_type(argname="argument fail_on_warning", value=fail_on_warning, expected_type=type_hints["fail_on_warning"])
+            check_type(argname="argument nag_packs", value=nag_packs, expected_type=type_hints["nag_packs"])
         self._values: typing.Dict[str, typing.Any] = {}
         if analytics_reporting is not None:
             self._values["analytics_reporting"] = analytics_reporting
@@ -519,6 +549,8 @@ class PDKNagAppProps(aws_cdk.AppProps):
             self._values["fail_on_error"] = fail_on_error
         if fail_on_warning is not None:
             self._values["fail_on_warning"] = fail_on_warning
+        if nag_packs is not None:
+            self._values["nag_packs"] = nag_packs
 
     @builtins.property
     def analytics_reporting(self) -> typing.Optional[builtins.bool]:
@@ -648,6 +680,15 @@ class PDKNagAppProps(aws_cdk.AppProps):
         result = self._values.get("fail_on_warning")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def nag_packs(self) -> typing.Optional[typing.List[cdk_nag.NagPack]]:
+        '''Custom nag packs to execute.
+
+        :default: DEFAULT_NAG_PACKS
+        '''
+        result = self._values.get("nag_packs")
+        return typing.cast(typing.Optional[typing.List[cdk_nag.NagPack]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
